@@ -284,9 +284,10 @@ ENAdata = R6::R6Class("ENAdata", public = list(
 
       if(is.function(private$weight.by)) {
         cols = colnames(self$adjacency.vectors)[grep("adjacency.code", colnames(self$adjacency.vectors))];
-        self$adjacency.vectors[, (cols) := lapply(.SD, private$weight.by), .SDcols = cols];
+        # self$adjacency.vectors[, (cols) := lapply(.SD, private$weight.by), .SDcols = cols];
+        # self$adjacency.vectors[, (cols) := lapply(.SD, private$weight.by), .SDcols = cols, by=c("ENA_ROW_IDX")];
+        self$adjacency.vectors = self$adjacency.vectors[,lapply(.SD, private$weight.by),.SDcols=cols,by=c("ENA_ROW_IDX")];
       }
-
       self$metadata = self$add.metadata(merge = F);
 
       ### remove non-adjacency vector columns from adj.vecs
